@@ -1,14 +1,12 @@
 /*
- * Calcoo: body_layout.c
+ * Calcoo: b_layout.c
  *
- * Copyright (C) 2001 Alexei Kaminski
+ * Copyright (C) 2001,2002 Alexei Kaminski
  *
- * mallocs the body
  * determines layout of the buttons
  * calls create_display()
  *
- * the sizes and layout of everything is defined here
- * (except for the layout of the display glyphs)
+ * the sizes and layout of everything are defined here
  */
 
 #include <stdlib.h>
@@ -19,7 +17,7 @@
 #include "displays.h"
 #include "const.h"
 #include "defaults.h"
-#include "body_headers.h"
+#include "b_headers.h"
 #include "io_headers.h"
 
 #define BUTTON_SIZE 32 /* buttons are square */
@@ -29,7 +27,7 @@
 #define TOP_MARGIN 8
 #define BOTTOM_MARGIN 8
 
-#define DISPLAY_SIZE_HORIZ 240 /*  224 */
+#define DISPLAY_SIZE_HORIZ 240 
 #define DISPLAY_SIZE_VERT BUTTON_SIZE
 #define UNDERDISPLAY_SPACING (BUTTON_SIZE / 2 )
 
@@ -43,8 +41,8 @@
 #define NUMBER_OF_COLS_IN_BLOCK_2 3
 #define NUMBER_OF_COLS_IN_BLOCK_3 4
 
-/* the offset of a block is the distance from the block's left brim
- * to the left brim of the calculator's body */
+/* the offset of a block is the distance from the block's left edge
+ * to the left edge of the calculator's body */
 
 #define	OFFSET_OF_BLOCK_0 LEFT_MARGIN
 
@@ -109,24 +107,20 @@
 
 #define REG_DISPLAY_LEFT_SHIFT (LEFT_MARGIN + 12)
 
-void create_body(void)
+void create_widgets(void)
 {
 	char **button_xpm[MAX_BUTTON_NUMBER],
-		**digit_xpm[D_G_TOTAL], 
-		**ldigit_xpm[D_G_TOTAL],
-		**op_xpm[OD_G_TOTAL],
-		**deg_rad_xpm[OD_G_TOTAL],
-		**format_xpm[OD_G_TOTAL],
+		**digit_xpm[NUMBER_OF_DISPLAY_GLYPHS], 
+		**ldigit_xpm[NUMBER_OF_DISPLAY_GLYPHS],
+		**op_xpm[NUMBER_OF_OPERATION_DISPLAY_GLYPHS],
+		**deg_rad_xpm[NUMBER_OF_ANGLE_UNIT_GLYPHS],
+		**format_xpm[NUMBER_OF_FORMAT_GLYPHS],
 		**reg_display_label_xpm[NUMBER_OF_REG_DISPLAYS];
 	
 	int i;
 
-	malloc_body();
-
 	create_main_window(BODY_SIZE_HORIZ, BODY_SIZE_VERT);
     
-	malloc_displays();
-
 	assign_pixmaps(button_xpm,
 		       digit_xpm, 
 		       ldigit_xpm,
@@ -154,7 +148,7 @@ void create_body(void)
 		       digit_xpm);
 
 	for(i = 0; i < NUMBER_OF_REG_DISPLAYS; i++){
-		create_display(REG_D_N_SHIFT + i,
+		create_display(REG_DISPLAY_OFFSET + i,
 			       REG_DISPLAY_LEFT_SHIFT,
 			       TOP_MARGIN + (NUMBER_OF_REG_DISPLAYS - i - 1) 
 			                    * MEM_DISPLAY_SIZE_VERT,
@@ -171,26 +165,27 @@ void create_body(void)
 			       TRUE, /* frame */ 
   			       ldigit_xpm); 
 
-		create_simple_display(i,
+		create_simple_display(OPERATION_DISPLAY_OFFSET + i,
 				      REG_DISPLAY_LEFT_SHIFT +
 				      MEM_DISPLAY_SIZE_HORIZ,
 				      TOP_MARGIN + 
 				      (NUMBER_OF_REG_DISPLAYS - i - 1) 
 				      * MEM_DISPLAY_SIZE_VERT,
 				      20, 16,
-				      OD_G_TOTAL,
+				      NUMBER_OF_OPERATION_DISPLAY_GLYPHS,
 				      TRUE, /* frame */ 
 				      op_xpm);
 
-		create_simple_display(NUMBER_OF_REG_DISPLAYS + i, 
+		create_simple_display(DISPLAY_LABEL_DISPLAY_OFFSET + i, 
 				      LEFT_MARGIN,
 				      TOP_MARGIN + 
 				      (NUMBER_OF_REG_DISPLAYS - i - 1) 
 				      * MEM_DISPLAY_SIZE_VERT,
 				      12, 16,
-				      LD_G_TOTAL,
+				      NUMBER_OF_REG_DISPLAYS,
 				      FALSE, /* frame */ 
 				      reg_display_label_xpm);
+		show_display_glyph(DISPLAY_LABEL_DISPLAY_OFFSET + i, i);
 	}
 
 /*======= Block 0 =====================================*/
@@ -202,13 +197,13 @@ void create_body(void)
 		      button_xpm, &clicked_change_angle_measure,
 		      NULL);
 
-	create_simple_display(I_DRD,
+	create_simple_display(ANGLE_UNIT_DISPLAY_OFFSET,
 			      OFFSET_OF_BLOCK_0, 
 			      LEFT_FOR_DISPLAY_VERT + INTERBLOCK_SPACING 
 		              + BUTTON_SIZE / 2, 
 			      BUTTON_SIZE, BUTTON_SIZE / 2,
-			      DRD_G_TOTAL,
-			      TRUE,
+			      NUMBER_OF_ANGLE_UNIT_GLYPHS,
+			      TRUE, /* frame */ 
 			      deg_rad_xpm);
 
 	create_button(CODE_INFO,
@@ -491,13 +486,14 @@ void create_body(void)
 		      button_xpm, &clicked_change_display_format,
 		      "Change display format");
 
-	create_simple_display(I_FD,		      
+	/* format display */
+	create_simple_display(FORMAT_DISPLAY_OFFSET,
 			      OFFSET_OF_BLOCK_2 + BUTTON_SIZE * 2, 
 			      LEFT_FOR_DISPLAY_VERT + INTERBLOCK_SPACING 
 		                      + BUTTON_SIZE * 4 + BUTTON_SIZE / 2, 
 			      BUTTON_SIZE, BUTTON_SIZE / 2,
-			      FD_G_TOTAL,
-			      TRUE,
+			      NUMBER_OF_FORMAT_GLYPHS,
+			      TRUE, /* frame */ 
 			      format_xpm);
 
 /*====== Block 3 ===============================================*/
@@ -554,11 +550,11 @@ void create_body(void)
 		      button_xpm, &clicked_code_eq, 
 		      NULL);
 
-	create_button(CODE_PUSH,
+	create_button(CODE_ENTER,
 		      OFFSET_OF_BLOCK_3 + BUTTON_SIZE * 2,  
 		      LEFT_FOR_DISPLAY_VERT + BUTTON_SIZE,  
 		      BUTTON_SIZE, BUTTON_SIZE,
-		      button_xpm, &clicked_code_push, 
+		      button_xpm, &clicked_code_enter, 
 		      "Enter");
 
 	create_button(CODE_REDO,
@@ -610,7 +606,7 @@ void create_body(void)
 		      LEFT_FOR_DISPLAY_VERT + BUTTON_SIZE * 2,
 		      BUTTON_SIZE, BUTTON_SIZE,
 		      button_xpm, &clicked_code_clear_x, 
-		      NULL);
+		      "Clear X");
 
 /*----- Block 3 Row 4 ----------------------------------------------*/
 
@@ -665,8 +661,11 @@ void create_body(void)
 		      button_xpm, &clicked_code_switch_to_mem1, 
 		      "Switch to memory register 1");
 
+	create_invisible_button(CODE_EXIT, &clicked_code_exit);
+
+
 	for(i = 0; i < NUMBER_OF_MEMS; i++)
-		create_display(MEM_D_N_SHIFT + i,
+		create_display(MEM_DISPLAY_OFFSET + i,
 			       MEM_DISPLAY_LEFT_SHIFT,
 			       MEM_DISPLAY_TOP_SHIFT + 
 			       i * MEM_DISPLAY_V_STEP,
@@ -683,7 +682,6 @@ void create_body(void)
 			       TRUE, /* frame */
 			       ldigit_xpm);
 
-	assign_accel();
 }
 
 
