@@ -16,7 +16,7 @@
 #include "const.h"
 #include "defaults.h"
 #include "cpu.h"
-#include "cpu_headers.h"
+#include "c_headers.h"
 #include "io_headers.h"
 #include "aux_headers.h"
 
@@ -60,15 +60,33 @@ void init_cpu(void)
 	cpu->prescribed_format = DEFAULT_DISPLAY_FORMAT;
 	cpu->angle_measure = DEFAULT_ANGLE_MEASURE;
 	cpu->curr_mem = 0;
-	/* slightly underestimated precision 
-	 * it is going to be used in evaluation of
-	 * trigonometric functions to get sin PI = 0 rather than 10^-17 */
-	cpu->precision = pow(10, -(INPUT_LENGTH - 1));
+	cpu->rpn_mode = FALSE ; /* It is a hack. We need it to have proper
+		* (to display nothing) initialization of the operation 
+		* displays. The reason is that cpu->rpn_mode is used in
+		* cpu_to_output(), and if it turns out to be set to TRUE
+		* after having been malloc'ed, cpu_to_output() skips
+		* resetting operation displays. If these displays contain
+		* some garbage after having been malloc'ed, it will lead to
+		* weird stuff displayed in the operation displays in the 
+		* algebraic mode from after initialization until the next
+		* call to cpu_to_output */
+	cpu->precision = pow(10, -(INPUT_LENGTH - 1));	/* slightly 
+		* underestimated precision 
+		* it is going to be used in evaluation of
+		* trigonometric functions to get sin PI = 0 
+		* rather than 10^-17 */
 	cpu_to_output();
 	init_undo_stack();
   	refresh_body(); 
 }
 
+void aftermath(void)
+{
+	cpu_to_output();
+	save_for_undo();
+	refresh_body();
+}
+
 void reset_registers(void)
 /* the function called by the "C" button" */
 {
@@ -115,14 +133,16 @@ void call_set_rpn_mode(int a)
 		reset_undo_stack();
 		reset_registers();
 		cpu->x = tmp;
-		cpu_to_output();
-		save_for_undo();
-		refresh_body();
+
 		if (a) {
 			cpu->rpn_mode = TRUE;
 		} else {
 			cpu->rpn_mode = FALSE;
-		}
+		} /* why not just "cpu->rpn_mode = a;"? I don't remember why */
+
+		cpu_to_output();
+		save_for_undo();
+		refresh_body();
 	}
 }
 
@@ -131,9 +151,9 @@ int call_get_rpn_mode(void)
 	return cpu->rpn_mode;
 }
 
-void call_set_enter_mode(int a)
+void call_set_enter_mode(int new_mode)
 {
-	cpu->enter_mode = a;
+	cpu->enter_mode = new_mode;
 }
 
 int call_get_enter_mode(void)
@@ -141,3 +161,15 @@ int call_get_enter_mode(void)
 	return cpu->enter_mode;
 }
 
+void call_set_stack_mode(int new_mode)
+{
+	cpu->stack_mode = new_mode;
+	if (new_mode == STACK_MODE_XYZT)
+		reset_stack(); /* resets stack only beyond T */
+}
+
+int call_get_stack_mode(void)
+{
+	return cpu->stack_mode;
+}
+
