@@ -1,17 +1,16 @@
 /*
- * Calcoo: cpu_mem.c
+ * Calcoo: c_mem.c
  *
- * Copyright (C) 2001 Alexei Kaminski
+ * Copyright (C) 2001, 2002 Alexei Kaminski
  *
- * handles keypressings for memory operations
+ * memory operations
  *
  */
 
-
 #include "const.h"
 #include "codes.h"
 #include "cpu.h"
-#include "cpu_headers.h"
+#include "c_headers.h"
 #include "io_headers.h"
 #include "aux_headers.h"
 
@@ -30,7 +29,7 @@ void call_mem_op(int received_code)
 			if (cpu->last_action == ACTION_INPUT) 
 				input_to_x();
 			push_stack(); 
-			cpu->op = CODE_PUSH;/* it should probably be removed */
+			cpu->op = CODE_ENTER; /* should be removed (?) */
 			cpu->y = cpu->x;
 		}
 		cpu->x = cpu->mem[cpu->curr_mem];
@@ -44,14 +43,12 @@ void call_mem_op(int received_code)
 		cpu->mem[cpu->curr_mem] = tmp;
 		break;
 	default:
-		error_occured("call_mem_op() unknown mem_op code",
-			      FALSE);
+		error_occured("call_mem_op() unknown mem_op code", FALSE);
   }
 
-	cpu_to_output();
 	cpu->last_action = ACTION_ENTER;
-	save_for_undo();
-	refresh_body();
+
+	aftermath();
 }
 
 void call_switch_to_mem(int m)
