@@ -1,7 +1,7 @@
 /*
  * Calcoo: defaults.h
  *
- * Copyright (C) 2001 Alexei Kaminski
+ * Copyright (C) 2001,2002 Alexei Kaminski
  *
  */
 
@@ -9,12 +9,19 @@
 #define DEFAULTS_H
 
 #include "codes.h"
+#include "const.h"
 
 #define DEFAULT_TOOLTIP_DELAY 1500
+
 #define DEFAULT_ANGLE_MEASURE CODE_DEG
 #define DEFAULT_DISPLAY_FORMAT FORMAT_FP
+
 #define DEFAULT_RPN_MODE FALSE
 #define DEFAULT_ENTER_MODE ENTER_MODE_TRADITIONAL
+#define DEFAULT_STACK_MODE STACK_MODE_XYZT
+
+#define DEFAULT_ARC_AUTORELEASE TRUE
+#define DEFAULT_HYP_AUTORELEASE TRUE
 
 #define UNDO_STACK_SIZE 64
 
