@@ -1,15 +1,14 @@
 /*
- *
  * Calcoo: main.c
  *
- * Copyright (C) 2001 Alexei Kaminski
+ * Copyright (C) 2001, 2002 Alexei Kaminski
  *
  */
 
 #include <gtk/gtk.h>
 
-#include "cpu_headers.h"
-#include "body_headers.h"
+#include "c_headers.h"
+#include "b_headers.h"
 
 int main (int argc, char *argv[])
 {
