@@ -12,7 +12,7 @@ static char *about_text[] =
 {
 	" ",
 	NULL,
-	"Calcoo 1.3.5 -  Scientific calculator",
+	"Calcoo " VERSION " -  Scientific calculator",
 	NULL,
 	"Copyright (C) 2001, 2002 Alexei Kaminski",
 	NULL,
@@ -48,8 +48,9 @@ static char *help_text[] =
 	"Even though it must be clear in general how to use calcoo,",
 	"some subtleties may need clarification.",
 	NULL,
-	"In the RPN mode, there are four registers, X, Y, Z, T, like in",
-	"real RPN calculators. In the algebraic mode, the number of",
+	"In the RPN mode, the stack either has four registers, X, Y, Z, T,",
+	"like in most real RPN calculators, or is unlimited, depending",
+	"on the corresponding option. In the algebraic mode, the number of",
 	"registers is unlimited, but only the lowest four have their",
 	"contents displayed.",
 	NULL,
@@ -93,6 +94,7 @@ static char *shortcuts_text[] =
 	"Ctrl-e", "change exp sign",
 	"?", "info/help",
 	"!", "options",
+	"Ctrl-q", "exit",
 	NULL, NULL, NULL, NULL
 };
 
@@ -100,19 +102,19 @@ static char *shortcuts_text[] =
 
 static char *version_console[] =
 {
-	"calcoo 1.3.5",
+	"calcoo " VERSION,
 	NULL
 };
 
 static char *help_console[] =
 {
 	"",
-	"Calcoo - scientific calculator (GTK+) Version 1.3.5",
+	"Calcoo - scientific calculator (GTK+) Version " VERSION,
 	"Copyright (C) 2001, 2002 Alexei Kaminski (kaminski@tpi.umn.edu)",
 	"Valid options:",
 	"    -v, --version for version info",
 	"    -h, --help to see this help",
-	" Run \"calcoo\" to start the program",
+	" Run \"calcoo\" to start the program.",
 	"",
 	NULL
 };
